SearchProvider

Trait SearchProvider 

pub trait SearchProvider: Send + Sync {
    // Required methods
    fn search(&self, query: &SearchQuery) -> Result<SearchResults>;
    fn capabilities(&self) -> SearchCapabilities;
}
Provides content and filename search within a filesystem scope.

Implementations are returned by SearchCapable::search_provider and execute queries against an index or other optimized data structure.

Required Methods

fn search(&self, query: &SearchQuery) -> Result<SearchResults>

Execute a content search query.

fn capabilities(&self) -> SearchCapabilities

Report what this provider can do.

Implementors