LazyLoader

Type Alias LazyLoader 

pub type LazyLoader = Arc<dyn Fn() -> Vec<u8> + Send + Sync>;
Lazy file content loader type.

Called at most once when the file is first read. The loader is never called if the file is overwritten before being read.

Aliased Type

pub struct LazyLoader { /* private fields */ }