pub type LazyLoader = Arc<dyn Fn() -> Vec<u8> + Send + Sync>;Expand description
Lazy file content loader type.
Called at most once when the file is first read. The loader is never called if the file is overwritten before being read.
Aliased Type
pub struct LazyLoader { /* private fields */ }